import request from '@/utils/request'

// 获取所有人员列表
export function getALLUserList() {
    return request({
        url: '/system/dept/userDeptList',
        method: 'get'
    })
}

// 查询CQC编制上方表头
export function listCqcCompilationTask(query) {
    return request({
        url: '/control/compilationTask/getCqcCompilationTaskInfo',
        method: 'get',
        params: query
    })
}

// 查询CQC编制关键零部件信息详细
export function getCQCKeyList(query) {
    return request({
        url: '/control/cqcKeyParts/list',
        method: 'get',
        params: query
    })
}

// 微调/填写检验文件编号/填写零件号/填写主数据接口
export function miniUpdateCQCParts(data) {
    return request({
        url: '/control/cqcKeyParts',
        method: 'put',
        data: data
    })
}

// 设置P8后批量生产单位
export function updataP8Producte(data){
    return request({
        url: '/control/cqcKeyParts/batchUpdateP8PostMassProductNumber',
        method: 'put',
        data: data
    })
}

// 完成填写接口
export function updateFinishTask(data) {
    return request({
        url: '/control/assignPerson/finishEntry',
        method: 'put',
        data: data
    })
}

// 取消完成接口
export function updateCancelFinishTask(data) {
    return request({
        url: '/control/assignPerson/cancelFinishEntry',
        method: 'put',
        data: data
    })
}

// 转交任务接口
export function updateTransferTask(data) {
    return request({
        url: '/control/compilationTask/transTask',
        method: 'put',
        data: data
    })
}

// 查看编制人群
export function getEntryPersons(taskId) {
    return request({
        url: '/control/assignPerson/getEntryPersons/' + taskId,
        method: 'get',
    })
}

// 分配任务接口
export function updateAssignTask(data) {
    return request({
        url: '/control/assignPerson/assignTask',
        method: 'put',
        data: data
    })
}

// 查询CQC控制计划变更履历列表
export function getCQCPlanChangeList(query) {
    return request({
        url: '/control/cqcPlan/changeLog/preview',
        method: 'get',
        params: query
    })
}

//填写批量退回
export function updateAssignTaskBack(data) {
    return request({
        url: '/control/assignPerson/assignTaskBack',
        method: 'put',
        data: data
    })
}

// 标记问题
export function updateFlagIssue(data) {
    return request({
        url: '/control/ccapKeyParts/flagIssue',
        method: 'put',
        data: data
    })
}

// 取消标记问题
export function updateCancelFlagIssue(data) {
    return request({
        url: '/control/ccapKeyParts/cancelFlagIssue',
        method: 'put',
        data: data
    })
}

// 审核通过/批准通过/最终确认
export function updateBtnNoPass(data) {
    return request({
        url: '/control/ccapPlan/btnBack',
        method: 'put',
        data: data
    })
}

// 审批人/批准人/最终确认人的退回接口
export function updateBtnPass(data) {
    return request({
        url: '/control/ccapPlan/btnPass',
        method: 'put',
        data: data
    })
}

// 查看退回记录
export function getBackRecords(taskId) {
    return request({
        url: '/control/nodeRecord/getBackRecords/' + taskId,
        method: 'get',
    })
}

// 确认提交接口
export function updateSubmitTask(data) {
    return request({
        url: '/control/ccapPlan/btnConfirm',
        method: 'put',
        data: data
    })
}

// 拉取检验文件编号接口
export function pullFileCheckData(data) {
    return request({
        url: '/control/cqcKeyParts/pullFileCheckData',
        method: 'put',
        data: data
    })
}

// 导出数据
export function exportKeyPartsData(params) {
    return request({
        url: '/control/cqcKeyParts/export',
        method: 'post',
        data: params,
        responseType: 'blob' // 关键点：声明响应类型为二进制流
    }).then(response => {
        // 创建下载链接并自动触发下载
        const blob = new Blob([response], { type: 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet' })
        const downloadUrl = URL.createObjectURL(blob)
        const link = document.createElement('a')
        link.href = downloadUrl
        link.download = 'CQC关键零部件清单.xlsx' // 设置默认文件名
        link.click()
        URL.revokeObjectURL(downloadUrl) // 释放内存
    })
}

//获取专业部门列表
export function listProfessionalDepartment(query) {
    return request({
        url: '/control/cqcKeyParts/professionalDepartmentList',
        method: 'get',
        params: query
    })
}

//获取当前任务审核人与批准人列表
export function listReviewApproveUser(query) {
    return request({
        url: '/control/cqcPlan/getUserList',
        method: 'get',
        params: query
    })
}
